# RDFProxy Examples

## Running examples

To run examples, execute `uv run`:

```shell
uv run fastapi dev examples/<path-to-examples>
```

This will run the FastAPI application on `http://127.0.0.1:8000`.
